==> libreoffice-fresh-sdk-24.8.4-2-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.js <==
var servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField =
[
    [ "XPropertySet", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "CellBackColor", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#ad8d45cf647e9e8810387ca159434a8c5", null ],
    [ "CharColor", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a33b11f2f20bb3cf8f0ed3f84fd8e3261", null ],
    [ "CharContoured", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a14e05635960c748d90958daa60506251", null ],
    [ "CharCrossedOut", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#aa50eadfd1e02b2fb82dd8ab29d907695", null ],
    [ "CharFontCharSet", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a57950a5a171b5a6a2ede65daf8e56fdf", null ],
    [ "CharFontCharSetAsian", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a235b4518ebb07e6c1f6697d9a1841fea", null ],
    [ "CharFontCharSetComplex", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#ad3c9e0459b04b270f5312a14f02808e5", null ],
    [ "CharFontFamily", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#afe885d200cc98ede6f3fa04c6217bd3a", null ],
    [ "CharFontFamilyAsian", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#add985e45d88d587fe204f68bae2ff657", null ],
    [ "CharFontFamilyComplex", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a9e714480f602b352679b9078b4322a19", null ],
    [ "CharFontName", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a72570751efb344dd58918fd8184ae205", null ],
    [ "CharFontNameAsian", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a2b430f4c42aa113014d6d567f0678306", null ],
    [ "CharFontNameComplex", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a21153c924dfa4023b4491d70e18c7211", null ],
    [ "CharFontPitch", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#abfbb255cd4b3245fa6dbdf4bc35a3d5f", null ],
    [ "CharFontPitchAsian", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a7f7d2f13cdf3ef64164cc162b933803f", null ],
    [ "CharFontPitchComplex", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#ab3f82a2aabd54892ee6fb636ee5c5132", null ],
    [ "CharFontStyleName", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a6236ed72e82facfeeae867ff49ea087a", null ],
    [ "CharFontStyleNameAsian", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#ad9e83b055db3e4ba176f4b994b0917ba", null ],
    [ "CharFontStyleNameComplex", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#ae52fc2b78584579cfd664879be257d4d", null ],
    [ "CharHeight", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#aa08540d4bc4215c00a7f20436666d374", null ],
    [ "CharHeightAsian", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a78c599a2cea0a18df991fc6fb4ef70b1", null ],
    [ "CharHeightComplex", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a990a44e52430c7ce72f2e5932ecc8768", null ],
    [ "CharPosture", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#af39ed64edee381d6f903b44888a7ec60", null ],
    [ "CharPostureAsian", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a307ca0ef2b983b62c326074b8060d511", null ],
    [ "CharPostureComplex", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a711ed6448dfc4c6e3c6d02d62f697de5", null ],
    [ "CharShadowed", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a46cd2a260e427be1b139724a8b10d9d9", null ],
    [ "CharUnderline", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a1db25b8e556787120742dd5729289979", null ],
    [ "CharWeight", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a3393f5ec24ee4a2c7123877a0ede9b19", null ],
    [ "CharWeightAsian", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a8d6f98620bcb05a8a4063ae7bd3712ea", null ],
    [ "CharWeightComplex", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#abb0f9abcc005befb7568661d6861039b", null ],
    [ "HoriJustify", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#ac4ecfad4d3b8fcf60e5205465fb254dd", null ],
    [ "IsCellBackgroundTransparent", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a14e19874edbc7814082222fdcf7210cf", null ],
    [ "IsTextWrapped", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a42d42ccd1a4db0519a39f481293bc287", null ],
    [ "Orientation", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a0b017e92895de0ad405c89b32f792d04", null ],
    [ "ParaBottomMargin", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a468a4fc42d26192c0eab945c470b27ad", null ],
    [ "ParaLeftMargin", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a9640f9110480558dcc66d794f67f57b8", null ],
    [ "ParaRightMargin", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a3ea3a3aad18ac347858caafeeb726977", null ],
    [ "ParaTopMargin", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#ac6ca70814d30943ebe921504dd41ea8f", null ],
    [ "RotateAngle", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a40f48292428d81d4d378a0682e90e01b", null ],
    [ "RotateReference", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a94df978260fcfddb4914e4d5371616cc", null ],
    [ "ShadowFormat", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a4ae00f2c00d7f00c846f71a516a72833", null ],
    [ "TableBorder", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a9305b410babc1d16e9f2c2b018de408e", null ],
    [ "TableBorder2", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a49bb684549420769cf181d267aa5c300", null ],
    [ "VertJustify", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a84a9df11fc686d6a57465a9be71d7477", null ]
];

==> libreoffice-fresh-sdk-25.8.3-3-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.js <==
var servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField =
[
    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "CellBackColor", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#ad8d45cf647e9e8810387ca159434a8c5", null ],
    [ "CharColor", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a33b11f2f20bb3cf8f0ed3f84fd8e3261", null ],
    [ "CharContoured", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a14e05635960c748d90958daa60506251", null ],
    [ "CharCrossedOut", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#aa50eadfd1e02b2fb82dd8ab29d907695", null ],
    [ "CharFontCharSet", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a57950a5a171b5a6a2ede65daf8e56fdf", null ],
    [ "CharFontCharSetAsian", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a235b4518ebb07e6c1f6697d9a1841fea", null ],
    [ "CharFontCharSetComplex", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#ad3c9e0459b04b270f5312a14f02808e5", null ],
    [ "CharFontFamily", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#afe885d200cc98ede6f3fa04c6217bd3a", null ],
    [ "CharFontFamilyAsian", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#add985e45d88d587fe204f68bae2ff657", null ],
    [ "CharFontFamilyComplex", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a9e714480f602b352679b9078b4322a19", null ],
    [ "CharFontName", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a72570751efb344dd58918fd8184ae205", null ],
    [ "CharFontNameAsian", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a2b430f4c42aa113014d6d567f0678306", null ],
    [ "CharFontNameComplex", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a21153c924dfa4023b4491d70e18c7211", null ],
    [ "CharFontPitch", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#abfbb255cd4b3245fa6dbdf4bc35a3d5f", null ],
    [ "CharFontPitchAsian", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a7f7d2f13cdf3ef64164cc162b933803f", null ],
    [ "CharFontPitchComplex", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#ab3f82a2aabd54892ee6fb636ee5c5132", null ],
    [ "CharFontStyleName", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a6236ed72e82facfeeae867ff49ea087a", null ],
    [ "CharFontStyleNameAsian", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#ad9e83b055db3e4ba176f4b994b0917ba", null ],
    [ "CharFontStyleNameComplex", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#ae52fc2b78584579cfd664879be257d4d", null ],
    [ "CharHeight", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#aa08540d4bc4215c00a7f20436666d374", null ],
    [ "CharHeightAsian", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a78c599a2cea0a18df991fc6fb4ef70b1", null ],
    [ "CharHeightComplex", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a990a44e52430c7ce72f2e5932ecc8768", null ],
    [ "CharPosture", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#af39ed64edee381d6f903b44888a7ec60", null ],
    [ "CharPostureAsian", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a307ca0ef2b983b62c326074b8060d511", null ],
    [ "CharPostureComplex", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a711ed6448dfc4c6e3c6d02d62f697de5", null ],
    [ "CharShadowed", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a46cd2a260e427be1b139724a8b10d9d9", null ],
    [ "CharUnderline", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a1db25b8e556787120742dd5729289979", null ],
    [ "CharWeight", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a3393f5ec24ee4a2c7123877a0ede9b19", null ],
    [ "CharWeightAsian", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a8d6f98620bcb05a8a4063ae7bd3712ea", null ],
    [ "CharWeightComplex", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#abb0f9abcc005befb7568661d6861039b", null ],
    [ "HoriJustify", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#ac4ecfad4d3b8fcf60e5205465fb254dd", null ],
    [ "IsCellBackgroundTransparent", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a14e19874edbc7814082222fdcf7210cf", null ],
    [ "IsTextWrapped", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a42d42ccd1a4db0519a39f481293bc287", null ],
    [ "Orientation", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a0b017e92895de0ad405c89b32f792d04", null ],
    [ "ParaBottomMargin", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a468a4fc42d26192c0eab945c470b27ad", null ],
    [ "ParaLeftMargin", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a9640f9110480558dcc66d794f67f57b8", null ],
    [ "ParaRightMargin", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a3ea3a3aad18ac347858caafeeb726977", null ],
    [ "ParaTopMargin", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#ac6ca70814d30943ebe921504dd41ea8f", null ],
    [ "RotateAngle", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a40f48292428d81d4d378a0682e90e01b", null ],
    [ "RotateReference", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a94df978260fcfddb4914e4d5371616cc", null ],
    [ "ShadowFormat", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a4ae00f2c00d7f00c846f71a516a72833", null ],
    [ "TableBorder", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a9305b410babc1d16e9f2c2b018de408e", null ],
    [ "TableBorder2", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a49bb684549420769cf181d267aa5c300", null ],
    [ "VertJustify", "servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormatField.html#a84a9df11fc686d6a57465a9be71d7477", null ]
];
